==> oscars_mgmnt-0.1.78.dev20231208+126-py3-none-any.whl: oscars_mgmnt/parser/es/sentinel5p.py <==
import re

from oscars_mgmnt.parser.es.es import ElasticsearchParser


class Sentinel5P_ES_Parser(ElasticsearchParser):
    def __init__(self, template=None, es_source_host=None, es_source_index=None):
        super().__init__('CGS_S5P.template' if template is None else template, es_source_host, es_source_index)
        self.regex_identifier = re.compile(r".*/(\w*_\d{8}_\w*)(?:($)|(/.*))")

    def specific_treatment(self, product_file_info, values):
        #remove processingmode from id
        old_title= values['title']
        new_title=old_title.replace('_OFFL','')
        new_title=new_title.replace('_NRTI','')
        new_title = new_title.replace('_RPRO','')
        values['title'] = new_title
        values['id'] = new_title


        uid = super().specific_treatment(product_file_info, values)
        self.fix_geometry(values, simplify=False)

        values['platformserialid'] = uid.split("_")[0]
        values['conformsto'] = "http://www.opengis.net/def/crs/EPSG/0/4326"

        #this can be different per producttype in future(different version)
        major_version = values['productVersion'][0:2] #V200 -> V2
        values['parentidentifier'] = "urn:eop:VITO:TERRASCOPE_S5P_L3_%s_%s" % (values['producttype'], major_version)    #urn:eop:VITO:TERRASCOPE_S5P_L3_NO2_TD_V1
        wms_layer = "TERRASCOPE_S5P_L3_%s_%s" % (values['producttype'], major_version)                                  #TERRASCOPE_S5P_L3_CH4_TY_V1
        # if "NO2_TD" in values["producttype"]:
        #     values['parentidentifier'] = "urn:eop:VITO:TERRASCOPE_S5P_L3_NO2_TD_V1"
        #     #values.pop('platformserialid', None)
        # elif "CO_TD" in values["producttype"]:
        #     values['parentidentifier'] = "urn:eop:VITO:TERRASCOPE_S5P_L3_CO_TD_V1"
        #     #values.pop('platformserialid', None)
        # elif "HCHO_TD" in values["producttype"]:
        #     values['parentidentifier'] = "urn:eop:VITO:TERRASCOPE_S5P_L3_HCHO_TD_V1"
        #     # values.pop('platformserialid', None)
        # elif "CH4_TD" in values["producttype"]:
        #     values['parentidentifier'] = "urn:eop:VITO:TERRASCOPE_S5P_L3_CH4_TD_V1"
        #     # values.pop('platformserialid', None)
        # elif "NO2_TM" in values["producttype"]:
        #     values['parentidentifier'] = "urn:eop:VITO:TERRASCOPE_S5P_L3_NO2_TM_V1"
        #     # values.pop('platformserialid', None)
        # elif "CO_TM" in values["producttype"]:
        #     values['parentidentifier'] = "urn:eop:VITO:TERRASCOPE_S5P_L3_CO_TM_V1"
        #     # values.pop('platformserialid', None)
        # elif "HCHO_TM" in values["producttype"]:
        #     values['parentidentifier'] = "urn:eop:VITO:TERRASCOPE_S5P_L3_HCHO_TM_V1"
        #     # values.pop('platformserialid', None)
        # elif "CH4_TM" in values["producttype"]:
        #     values['parentidentifier'] = "urn:eop:VITO:TERRASCOPE_S5P_L3_CH4_TM_V1"
        #     # values.pop('platformserialid', None)
        # elif "NO2_TY" in values["producttype"]:
        #     values['parentidentifier'] = "urn:eop:VITO:TERRASCOPE_S5P_L3_NO2_TY_V1"
        #     # values.pop('platformserialid', None)
        # elif "CO_TY" in values["producttype"]:
        #     values['parentidentifier'] = "urn:eop:VITO:TERRASCOPE_S5P_L3_CO_TY_V1"
        #     # values.pop('platformserialid', None)
        # elif "HCHO_TY" in values["producttype"]:
        #     values['parentidentifier'] = "urn:eop:VITO:TERRASCOPE_S5P_L3_HCHO_TY_V1"
        #     # values.pop('platformserialid', None)
        # elif "CH4_TY" in values["producttype"]:
        #     values['parentidentifier'] = "urn:eop:VITO:TERRASCOPE_S5P_L3_CH4_TY_V1"
        #     # values.pop('platformserialid', None)


        self.add_wms_quicklook(wms_layer, product_file_info, values)

        return uid


    def fix_products(self, fileobject):
        #S5P_NO2_TD_20200131_NO2_V100.tif|S5P_NO2_TD_20200131_WEIGHT_V100.tif
        s5p_main_pattern = re.compile(".*S5P_([NO2HC4_TDMY]*)_[0-9]{4,8}_([NO2CH4]{2,6})_V[0-9]{3}.tif")
        s5p_weight_pattern = re.compile(".*S5P_([NO2HC4_TDMY]*)_[0-9]{4,8}_([WEIGHT]{2,6})_V[0-9]{3}.tif")

        for info in list(fileobject.datas):
            if s5p_main_pattern.match(info.name):
                m=s5p_main_pattern.search(info.name)
                info.title = m.group(2)
            if s5p_weight_pattern.match(info.name):
                m=s5p_weight_pattern.search(info.name)
                info.category = "QUALITY"
                info.title = m.group(2)
                fileobject.datas.remove(info)
                fileobject.related.append(info)

==> oscars_mgmnt-0.1.79.dev20240913+132-py3-none-any.whl: oscars_mgmnt/parser/es/sentinel5p.py <==
import re

from oscars_mgmnt.parser.es.es import ElasticsearchParser


class Sentinel5P_ES_Parser(ElasticsearchParser):
    def __init__(self, template=None, es_source_host=None, es_source_index=None):
        super().__init__('CGS_S5P.template' if template is None else template, es_source_host, es_source_index)
        self.regex_identifier = re.compile(r".*/(\w*_\d{8}_\w*)(?:($)|(/.*))")

    def specific_treatment(self, product_file_info, values):
        #remove processingmode from id
        old_title= values['title']
        new_title=old_title.replace('_OFFL','')
        new_title=new_title.replace('_NRTI','')
        new_title = new_title.replace('_RPRO','')
        values['title'] = new_title
        values['id'] = new_title


        uid = super().specific_treatment(product_file_info, values)
        self.fix_geometry(values, simplify=False)

        values['platformserialid'] = uid.split("_")[0]
        values['conformsto'] = "http://www.opengis.net/def/crs/EPSG/0/4326"

        #this can be different per producttype in future(different version)
        major_version = values['productVersion'][0:2] #V200 -> V2
        values['parentidentifier'] = "urn:eop:VITO:TERRASCOPE_S5P_L3_%s_%s" % (values['producttype'], major_version)    #urn:eop:VITO:TERRASCOPE_S5P_L3_NO2_TD_V1
        wms_layer = "TERRASCOPE_S5P_L3_%s_%s" % (values['producttype'], major_version)                                  #TERRASCOPE_S5P_L3_CH4_TY_V1
        comp_type = values['producttype'].split('_')[-1]  #TD/TM/TY
        if "NO2SF" in values["producttype"]:
            wms_layer = "TERRASCOPE_S5P_L3_NO2_SURFACE_%s_%s" % (comp_type, major_version)
        if "NO2EU" in values["producttype"]:
            wms_layer = "TERRASCOPE_S5P_L3_NO2_CAMS_%s_%s" % (comp_type, major_version)

            # if "NO2_TD" in values["producttype"]:
        #     values['parentidentifier'] = "urn:eop:VITO:TERRASCOPE_S5P_L3_NO2_TD_V1"
        #     #values.pop('platformserialid', None)
        # elif "CO_TD" in values["producttype"]:
        #     values['parentidentifier'] = "urn:eop:VITO:TERRASCOPE_S5P_L3_CO_TD_V1"
        #     #values.pop('platformserialid', None)
        # elif "HCHO_TD" in values["producttype"]:
        #     values['parentidentifier'] = "urn:eop:VITO:TERRASCOPE_S5P_L3_HCHO_TD_V1"
        #     # values.pop('platformserialid', None)
        # elif "CH4_TD" in values["producttype"]:
        #     values['parentidentifier'] = "urn:eop:VITO:TERRASCOPE_S5P_L3_CH4_TD_V1"
        #     # values.pop('platformserialid', None)
        # elif "NO2_TM" in values["producttype"]:
        #     values['parentidentifier'] = "urn:eop:VITO:TERRASCOPE_S5P_L3_NO2_TM_V1"
        #     # values.pop('platformserialid', None)
        # elif "CO_TM" in values["producttype"]:
        #     values['parentidentifier'] = "urn:eop:VITO:TERRASCOPE_S5P_L3_CO_TM_V1"
        #     # values.pop('platformserialid', None)
        # elif "HCHO_TM" in values["producttype"]:
        #     values['parentidentifier'] = "urn:eop:VITO:TERRASCOPE_S5P_L3_HCHO_TM_V1"
        #     # values.pop('platformserialid', None)
        # elif "CH4_TM" in values["producttype"]:
        #     values['parentidentifier'] = "urn:eop:VITO:TERRASCOPE_S5P_L3_CH4_TM_V1"
        #     # values.pop('platformserialid', None)
        # elif "NO2_TY" in values["producttype"]:
        #     values['parentidentifier'] = "urn:eop:VITO:TERRASCOPE_S5P_L3_NO2_TY_V1"
        #     # values.pop('platformserialid', None)
        # elif "CO_TY" in values["producttype"]:
        #     values['parentidentifier'] = "urn:eop:VITO:TERRASCOPE_S5P_L3_CO_TY_V1"
        #     # values.pop('platformserialid', None)
        # elif "HCHO_TY" in values["producttype"]:
        #     values['parentidentifier'] = "urn:eop:VITO:TERRASCOPE_S5P_L3_HCHO_TY_V1"
        #     # values.pop('platformserialid', None)
        # elif "CH4_TY" in values["producttype"]:
        #     values['parentidentifier'] = "urn:eop:VITO:TERRASCOPE_S5P_L3_CH4_TY_V1"
        #     # values.pop('platformserialid', None)


        self.add_wms_quicklook(wms_layer, product_file_info, values)

        return uid


    def fix_products(self, fileobject):
        #S5P_NO2_TD_20200131_NO2_V100.tif|S5P_NO2_TD_20200131_WEIGHT_V100.tif
        s5p_main_pattern = re.compile(".*S5P_([NO2SFEUHC4_TDMY]*)_[0-9]{4,8}_([NO2EUSFCH4]{2,6})_V[0-9]{3}.tif")
        #estimated_surface_no2_bencqe_20240424_1km_V200.tif
        s5p_weight_pattern = re.compile(".*S5P_([NO2SFEUHC4_TDMY]*)_[0-9]{4,8}_([WEIGHT]{2,6})_V[0-9]{3}.tif")

        for info in list(fileobject.datas):

            if s5p_main_pattern.match(info.name):
                m=s5p_main_pattern.search(info.name)
                info.title = m.group(2)
            else:
                import os
                info.title =os.path.basename(info.name)
            if s5p_weight_pattern.match(info.name):
                m=s5p_weight_pattern.search(info.name)
                info.category = "QUALITY"
                info.title = m.group(2)
                fileobject.datas.remove(info)
                fileobject.related.append(info)
